<?php

namespace Drupal\toggle_channels\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SettingsForm
 */
class SettingsForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'toggle_channels.settings';

  const FORM_ID = 'toggle_channels_admin_settings';

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return self::FORM_ID;
  }

  /**
   * {@inheritDoc}
   */
  protected function getEditableConfigNames() {
    return [
      self::SETTINGS,
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Get configurations
    $config = $this->configFactory()->getEditable(self::SETTINGS);

    $form['logger'] = [
      '#type' => 'details',
      '#open' => true,
      '#title' => $this->t('logger.factory')
    ];

    $form['logger']['toggle_logger'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Disable logger.factory service\'s channels'),
      '#description' => $this->t('Enabling this option all below checked channels will be disabled and no more logged.'),
      '#default_value' => $config->get('toggle_logger') ?? false,
    ];

    /** @var array $channels */
    $channels = $this->getLogChannels();

    /** @var array $options */
    $options = [];

    foreach ($channels as $channel) {
      $options[$channel->type] = $channel->type;
    }

    $form['logger']['toggle_channels'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Select channels to disable'),
      '#default_value' => $config->get('toggle_channels') ?? [],
      '#options' => $options
    ];

    return parent::buildForm($form, $form_state); // TODO: Change the autogenerated stub
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Get configurations
    $config = $this->configFactory()->getEditable(self::SETTINGS);

    $config
      ->set('toggle_logger', $form_state->getValue('toggle_logger'))
      ->set('toggle_channels', $form_state->getValue('toggle_channels'))
      ->save();

    parent::submitForm($form, $form_state); // TODO: Change the autogenerated stub
  }

  /**
   * @return mixed
   */
  private function getLogChannels() {
    $database = \Drupal::database();
    $query = $database->select('watchdog', 'w');

    return $query->fields('w', ['type'])->distinct(true)
      ->execute()->fetchAll();
  }
}
